# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .get_credentials import *
from .get_image import *
from .get_repository import *
from .lifecycle_policy import *
from .repository import *
from .repository_policy import *
